/*
 * Copyright 2011 Apaq.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package dk.apaq.crud;

/**
 *  Event used when Crud's notifies of its actions.
 */
public class CrudEvent<IDT, BT> {

    private final Crud<IDT, BT> crud;
    
    public CrudEvent(Crud<IDT, BT> crud) {
        this.crud = crud;
    }

    public Crud<IDT, BT> getCrud() {
        return crud;
    }

    

    public static class WithId<IDT, BT> extends CrudEvent<IDT, BT> {

        private final IDT id;

        public WithId(Crud<IDT,BT> crud, IDT id) {
            super(crud);
            this.id = id;
        }

        public IDT getEntityId() {
            return id;
        }
    }

    public static class WithEntity<IDT, BT> extends WithId<IDT, BT> {

        private final BT bean;

        public WithEntity(Crud<IDT, BT> crud, IDT id, BT bean) {
            super(crud, id);
            this.bean = bean;
        }

        public BT getEntity() {
            return bean;
        }
    }
}
