/*
 * Copyright 2011 Apaq.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package dk.apaq.crud;

/**
 * Interface for listeners of Crud actions.
 */
public interface CrudListener<IDT, BT> {

    /**
     * Called before an entity is read.
     */
    void onBeforeEntityRead(CrudEvent.WithId<IDT, BT> event);

    /**
     * Called when an entity is read.
     */
    void onEntityRead(CrudEvent.WithEntity<IDT, BT> event);

    /**
     * Called before an entity is deleted.
     */
    void onBeforeEntityDelete(CrudEvent.WithId<IDT, BT> event);

    /**
     * Called when an entity is deleted.
     * @param event
     */
    void onEntityDelete(CrudEvent.WithId<IDT, BT> event);

    /**
     * Called before an entity is being persisted.
     */
    void onBeforeEntityUpdate(CrudEvent.WithEntity<IDT, BT> event);

    /**
     * Called when an entity is persisted.
     * @param event
     */
    void onEntityUpdate(CrudEvent.WithEntity<IDT, BT> event);

    /**
     * Called before an entity is created.
     */
    void onBeforeEntityCreate(CrudEvent<IDT, BT> event);

    /**
     * Called when an entity is created.
     */
    void onEntityCreate(CrudEvent.WithEntity<IDT, BT> event);
}

