package dk.apaq.crud.core;

import dk.apaq.crud.Crud;
import dk.apaq.crud.CrudEvent;
import dk.apaq.crud.CrudListener;
import dk.apaq.crud.HasId;
import dk.apaq.filter.Filter;
import dk.apaq.filter.limit.Limit;
import dk.apaq.filter.sort.Sorter;
import java.util.List;

/**
 *
 */
public abstract class BaseCompleteCrud<IDT, BT> extends BaseCrud<IDT, BT> implements Crud.Complete<IDT, BT> {
    /**
     * Tells listeners that a new entity is about to be created.
     */
    protected void fireOnBeforeCreate() {
        CrudEvent e = createEvent();

        for (CrudListener listener : listeners) {
            listener.onBeforeEntityCreate(e);
        }
    }

    /**
     * Tells listeners that an entity is about to be updated.
     * @param entity The entity that holds changes and is about to be persisted.
     */
    protected void fireOnBeforeUpdate(IDT id, BT entity) {
        CrudEvent.WithEntity e = createEventWithEntity(id, entity);

        for (CrudListener listener : listeners) {
            listener.onBeforeEntityUpdate(e);
        }
    }

    /**
     * Tells listeners that an eneity is about to be deleted.
     * @param id The id of the entity that is about to be deleted.
     */
    protected void fireOnBeforeDelete(IDT id) {
        CrudEvent.WithId e = createEventWithId(id);
        for (CrudListener listener : listeners) {
            listener.onBeforeEntityDelete(e);
        }
    }

    /**
     * Tells listeners that an entity has been created.
     * @param entity The entity that was created.
     */
    protected void fireOnCreate(IDT id, BT entity) {
        CrudEvent.WithEntity e = createEventWithEntity(id, entity);

        for (CrudListener listener : listeners) {
            listener.onEntityCreate(e);
        }
    }

    /**
     * Tells listeners that an entity was updated.
     * @param entity The entity that was updated.
     */
    protected void fireOnUpdate(IDT id, BT entity) {
        CrudEvent.WithEntity e = createEventWithEntity(id, entity);

        for (CrudListener listener : listeners) {
            listener.onEntityUpdate(e);
        }
    }

    /**
     * Tells listeners that an entity was deleted.
     * @param id The id of the entity that was deleted.
     */
    protected void fireOnDelete(IDT id) {
        CrudEvent.WithId e = createEventWithId(id);
        for (CrudListener listener : listeners) {
            listener.onEntityDelete(e);
        }
    }

    public List<IDT> listIds() {
        return listIds(null, null, null);
    }

    public List<IDT> listIds(Limit limit) {
        return listIds(null, null, limit);
    }

    public List<IDT> listIds(Filter filter, Sorter sorter) {
        return listIds(filter, sorter, null);
    }

}
