/*
 * Copyright 2011 Apaq.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package dk.apaq.crud.core;

import dk.apaq.crud.CrudEvent;
import dk.apaq.crud.CrudListener;
import dk.apaq.crud.HasId;

/**
 * An abstract implementation of a <code>CrudListener</code> that has empty implementations
 * of all methods in  the interface. A class can extend this class and only implement the methods it need.
 */
public abstract class BaseCrudListener<IDT, BT> implements CrudListener<IDT, BT> {

    @Override
    public void onBeforeEntityCreate(CrudEvent<IDT, BT> event) { /* EMPTY */ }

    @Override
    public void onBeforeEntityDelete(CrudEvent.WithId<IDT, BT> event) { /* EMPTY */ }

    @Override
    public void onBeforeEntityRead(CrudEvent.WithId<IDT, BT> event) { /* EMPTY */ }

    @Override
    public void onBeforeEntityUpdate(CrudEvent.WithEntity<IDT, BT> event) { /* EMPTY */ }

    @Override
    public void onEntityCreate(CrudEvent.WithEntity<IDT, BT> event) { /* EMPTY */ }

    @Override
    public void onEntityDelete(CrudEvent.WithId<IDT, BT> event) { /* EMPTY */ }

    @Override
    public void onEntityRead(CrudEvent.WithEntity<IDT, BT> event) { /* EMPTY */ }

    @Override
    public void onEntityUpdate(CrudEvent.WithEntity<IDT, BT> event) { /* EMPTY */ }


}
